summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/debuggerpart.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/debuggerpart.cpp')
-rw-r--r--languages/cpp/debugger/debuggerpart.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/languages/cpp/debugger/debuggerpart.cpp b/languages/cpp/debugger/debuggerpart.cpp
index 3cae3762..f2379ccb 100644
--- a/languages/cpp/debugger/debuggerpart.cpp
+++ b/languages/cpp/debugger/debuggerpart.cpp
@@ -23,7 +23,7 @@
#include <tdeaction.h>
#include <kdebug.h>
#include <tdefiledialog.h>
-#include <kdevgenericfactory.h>
+#include <tdevgenericfactory.h>
#include <kiconloader.h>
#include <tdelocale.h>
#include <tdemainwindow.h>
@@ -37,12 +37,12 @@
#include <kstringhandler.h>
#include <kdockwidget.h>
-#include "kdevcore.h"
-#include "kdevproject.h"
-#include "kdevmainwindow.h"
-#include "kdevappfrontend.h"
-#include "kdevpartcontroller.h"
-#include "kdevdebugger.h"
+#include "tdevcore.h"
+#include "tdevproject.h"
+#include "tdevmainwindow.h"
+#include "tdevappfrontend.h"
+#include "tdevpartcontroller.h"
+#include "tdevdebugger.h"
#include "domutil.h"
#include "variablewidget.h"
#include "gdbbreakpointwidget.h"
@@ -61,7 +61,7 @@
#include <iostream>
-#include <kdevplugininfo.h>
+#include <tdevplugininfo.h>
#include <debugger.h>
@@ -71,13 +71,13 @@
namespace GDBDebugger
{
-static const KDevPluginInfo data("kdevdebugger");
+static const TDevPluginInfo data("tdevdebugger");
-typedef KDevGenericFactory<DebuggerPart> DebuggerFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevdebugger, DebuggerFactory( data ) )
+typedef TDevGenericFactory<DebuggerPart> DebuggerFactory;
+K_EXPORT_COMPONENT_FACTORY( libtdevdebugger, DebuggerFactory( data ) )
DebuggerPart::DebuggerPart( TQObject *parent, const char *name, const TQStringList & ) :
- KDevPlugin( &data, parent, name ? name : "DebuggerPart" ),
+ TDevPlugin( &data, parent, name ? name : "DebuggerPart" ),
controller(0), previousDebuggerState_(s_dbgNotStarted),
justRestarted_(false), needRebuild_(true),
running_(false)
@@ -85,7 +85,7 @@ DebuggerPart::DebuggerPart( TQObject *parent, const char *name, const TQStringLi
setObjId("DebuggerInterface");
setInstance(DebuggerFactory::instance());
- setXMLFile("kdevdebugger.rc");
+ setXMLFile("tdevdebugger.rc");
m_debugger = new Debugger( partController() );
@@ -333,8 +333,8 @@ DebuggerPart::DebuggerPart( TQObject *parent, const char *name, const TQStringLi
connect( core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)) );
- connect( core(), TQT_SIGNAL(stopButtonClicked(KDevPlugin*)),
- this, TQT_SLOT(slotStop(KDevPlugin*)) );
+ connect( core(), TQT_SIGNAL(stopButtonClicked(TDevPlugin*)),
+ this, TQT_SLOT(slotStop(TDevPlugin*)) );
connect( core(), TQT_SIGNAL(projectClosed()),
this, TQT_SLOT(projectClosed()) );
@@ -858,7 +858,7 @@ void DebuggerPart::slotRun()
if (rebuild)
{
disconnect(TQT_SIGNAL(buildProject()));
// The KDevProject has no method to build the project,
// so try connecting to a slot has is present to all
// existing project managers.
// Note: this assumes that 'slotBuild' will save
@@ -984,7 +984,7 @@ bool DebuggerPart::attachProcess(int pid)
}
-void DebuggerPart::slotStop(KDevPlugin* which)
+void DebuggerPart::slotStop(TDevPlugin* which)
{
if( which != 0 && which != this )
return;
@@ -1259,12 +1259,12 @@ bool DebuggerPart::haveModifiedFiles()
}
-KDevAppFrontend * GDBDebugger::DebuggerPart::appFrontend( )
+TDevAppFrontend * GDBDebugger::DebuggerPart::appFrontend( )
{
- return extension<KDevAppFrontend>("TDevelop/AppFrontend");
+ return extension<TDevAppFrontend>("TDevelop/AppFrontend");
}
-KDevDebugger * GDBDebugger::DebuggerPart::debugger()
+TDevDebugger * GDBDebugger::DebuggerPart::debugger()
{
return m_debugger;
}
@@ -858,7 +858,7 @@ void DebuggerPart::slotRun()
{
disconnect(TQT_SIGNAL(buildProject()));
- // The KDevProject has no method to build the project,
+ // The TDevProject has no method to build the project,
// so try connecting to a slot has is present to all
// existing project managers.